package aspects.dataManagement.dataCollections.array;

import healthGuide.HealthUnit;
import healthGuide.IHealthUnitRepository;
import healthGuide.ISpecialtyRepository;

import util.ConcreteIterator;
import util.IRepositorioIterable;
import util.IteratorHW;

import exceptions.ObjectNotFoundException;


public class HealthUnitRepositoryArray implements IHealthUnitRepository, IRepositorioIterable {

    private HealthUnit[] vector;
    private int index;
    private int iteratorIndex;

    public HealthUnitRepositoryArray() {
        vector  = new HealthUnit[5000];
        index = 0;
    }

    public void insert(HealthUnit unit)  {
        
        if (unit == null) {
            throw new IllegalArgumentException();
        }
        
        this.vector[index] = unit;
        index++;
    }

    public void update(HealthUnit unit) throws ObjectNotFoundException {
        int i = getIndex(unit.getCode());
        if (i == index) {
            throw new ObjectNotFoundException("Health unit not found");
        } else {
            vector[i] = unit;
        }
    }

    public HealthUnit search(int code) throws ObjectNotFoundException {
        HealthUnit response = null;
        int i = getIndex(code);
        if (i == index) {
            throw new ObjectNotFoundException("Health unit not found");
        } else {
            response = vector[i];
        }
        return response;               
    }


    public boolean exists(int code) {
        int indexAux = 0;
        boolean flag = false;

        for (int i = 0; i < index; i++) {
            if (this.vector[i].getCode() == code) {
                indexAux = i;
                flag    = true;
                break;
            }
        }
        return flag;
    }
        
    public void remove(int code) throws ObjectNotFoundException {
        int i = getIndex(code);
        if (i == index) {
            throw new ObjectNotFoundException("Health unit not found");
        } else {
            vector[i] = vector[index-1];
            index = index - 1;
        }    
    }
    
    private int getIndex(int code) {
        int temp;
        boolean flag = false;
        int i = 0;
        while ( (!flag) && (i < index) ) {
            temp = vector[i].getCode();
            if (temp == code) {
                flag = true;
            } else {
                i = i + 1;
            }
        }
        return i;
    }    

 
    public IteratorHW getHealthUnitList() throws ObjectNotFoundException {
        if (index == 0) throw new ObjectNotFoundException("There isn't registered Health units");
        return new ConcreteIterator(this);
    }
     
    public IteratorHW getHealthUnitListBySpecialty(int code) {

        int aux = 0;
        boolean has = false;    
        HealthUnitRepositoryArray response = new HealthUnitRepositoryArray();

        while (aux < index) {

            ISpecialtyRepository specialties = vector[aux].getSpecialties();

            if (specialties != null) {
                    if (specialties.exists(code)) {
                        has = true;
                        response.insert(vector[aux]);
                    }
            }
            aux++;
        }

        if (has) {
            return new ConcreteIterator(response);
        } else {
            return new ConcreteIterator(null);
        }
    }

     
    // iterator methods
    public void reset() {
        this.iteratorIndex = 0;
    }
    
    public Object next() {
        if (iteratorIndex >= index) {
            return null;
        } else {
            return vector[iteratorIndex++];
        }
    }

    public boolean hasNext() {
        return iteratorIndex < index;
    }
    
}