package aspects.dataManagement.dataCollections.array;

import healthGuide.ISpecialtyRepository;
import healthGuide.MedicalSpecialty;
import util.ConcreteIterator;
import util.IRepositorioIterable;
import util.IteratorHW;
import exceptions.ObjectNotFoundException;


public class SpecialtyRepositoryArray implements ISpecialtyRepository, IRepositorioIterable {

    private MedicalSpecialty[] vector;
    private int index;
    private int iteratorIndex;

    public SpecialtyRepositoryArray() {
        vector  = new MedicalSpecialty[5000];
        index = 0;
    }
    
    public void insert(MedicalSpecialty specialty)  {
        
        if (specialty == null) {
            throw new IllegalArgumentException();
        }
        
        this.vector[index] = specialty;
        index++;
    }

    public void update(MedicalSpecialty specialty) throws ObjectNotFoundException {
        int i = getIndex(specialty.getCode());
        if (i == index) {
            throw new ObjectNotFoundException("Specialty not found");
        } else {
            vector[i] = specialty;
        }
    }

    public MedicalSpecialty search(int code) throws ObjectNotFoundException {
        MedicalSpecialty response = null;
        int i = getIndex(code);
        if (i == index) {
            throw new ObjectNotFoundException("Specialty not found");
        } else {
            response = vector[i];
        }
        return response;               
    }


    public boolean exists(int code) {
        int indexAux = 0;
        boolean flag = false;

        for (int i = 0; i < index; i++) {
            if (this.vector[i].getCode() == code) {
                indexAux = i;
                flag    = true;
                break;
            }
        }
        return flag;
    }
        
    public void remove(int code) throws ObjectNotFoundException {
        int i = getIndex(code);
        if (i == index) {
            throw new ObjectNotFoundException("Specialty not found");
        } else {
            vector[i] = vector[index-1];
            index = index - 1;
        }    
    }
    
    private int getIndex(int code) {
        int temp;
        boolean flag = false;
        int i = 0;
        while ( (!flag) && (i < index) ) {
            temp = vector[i].getCode();
            if (temp == code) {
                flag = true;
            } else {
                i = i + 1;
            }
        }
        return i;
    }    

 
    public IteratorHW getSpecialtyList() throws ObjectNotFoundException  {
        if (index == 0) throw new ObjectNotFoundException("There isn't registered Health units");
        return new ConcreteIterator(this);
    }
     
    // iterator methods
    public void reset() {
        this.iteratorIndex = 0;
    }
    
    public Object next() {
        if (iteratorIndex >= index) {
            return null;
        } else {
            return vector[iteratorIndex++];
        }
    }

    public boolean hasNext() {
        return iteratorIndex < index;
    }
    
}