package aspects.dataManagement.persistent.util;

import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import util.Util;
import aspects.dataManagement.dataCollections.rdbms.PersistenceMechanismRDBMS;

public class GerenciaTabelas {
    
    public static final String[] TABELAS = {"_QUEIXADIVERSA",
                                            "_QUEIXADOENCA",
                                            "_QUEIXAALIMENTAR",
                                            "_QUEIXAANIMAL",
                                            "_TIPODOENCASINTOMA",
                                            "_TIPODOENCA",
                                            "_SINTOMA",
                                            "_UNIDADEESPECIALIDADE",
                                            "_UNIDADESAUDE",
                                            "_ESPECIALIDADE",
                                            "_QUEIXA",
                                            "_FUNCIONARIO"};

    private static Statement stmt;
    private static String login;    
    
    
    
    private GerenciaTabelas(Statement stmt) throws SQLException {
		GerenciaTabelas.stmt = stmt;
    }
    
    private static void removerTabela(String nome) throws SQLException {
        String sql = "DROP TABLE " + nome;
        executarSQL(sql);
    }

    private static void esvaziarTabela(String nome) throws SQLException {
        String sql = "TRUNCATE TABLE " + nome;
        executarSQL(sql);
    }
    
    private static void criarTabela(String sql) throws SQLException {
        try {
            executarSQL(sql);
        } catch(SQLException ex) {
            System.out.println(ex.getMessage());
            System.out.println(sql);
        }                        
    }

    private static void executarSQL(String sql) throws SQLException {
        if (sql == null) {
            throw new IllegalArgumentException("parametro invalido");
        }
        System.out.println(sql);
        stmt.executeUpdate(sql); 
    }


    public static void main(String[] args) {
        PersistenceMechanismRDBMS pm = null;
        try {
            pm = PersistenceMechanismRDBMS.getInstance();
            pm.connect();
            Statement stmt = (Statement) pm.getCommunicationChannel();
            GerenciaTabelas gerencia = new GerenciaTabelas(stmt);
            main();
        }
        catch (Exception ex) {
            System.out.println(ex.getMessage());
            System.out.println(ex.getMessage()); //ex.printStackTrace();
        } finally {
            try {
                if (stmt != null) {
                    stmt.close();
                }            
            } catch (Exception ex) {
                System.out.println(ex.getMessage()); //ex.printStackTrace();                
                System.out.println("Erro! 2");
            }
            try {
                pm.releaseCommunicationChannel();
            } catch (Exception ex) {
                System.out.println(ex.getMessage()); //ex.printStackTrace();                
                System.out.println("Erro! 3");
            }
            try {
                pm.disconnect();
            } catch (Exception ex) {
                System.out.println(ex.getMessage()); //ex.printStackTrace();                                
                System.out.println("Erro! 4");
            }                
        }                
    }
    
    private static void main() throws Exception {               
        System.out.println("Digite o seu login para identificar suas tabelas");
        login = Util.readStr();
        m();
    }
    
    private static void m() throws Exception {
        String sql;
        System.out.println("Escolha uma opo");
        System.out.println("1 - Criar   base");
        System.out.println("2 - Limpar  base");
        System.out.println("3 - Remover base");
        System.out.println("4 - Executar select");
        System.out.println("5 - Executar update");        
        System.out.println("6 - Mudar login");        
        System.out.println("7 - Sair");                
        int opcao = Util.readInt();
        switch (opcao) {
            case 1: criarTabelas();
                    System.out.println("Tabelas criadas");
                    povoarTabelas();
                    System.out.println("Tabelas de dados bsicos povoadas");
                    break;
                    
            case 2: esvaziarTabelas();
                    System.out.println("Tabelas esvaziadas");
                    povoarTabelas();
                    System.out.println("Tabelas de dados bsicos povoadas");
                    break;
                     
            case 3: removerTabelas();
                    System.out.println("Tabelas removidas");
                    break;

            case 4: System.out.println("Digite o comando sql (apenas a primeira coluna ser apresentada)");
                    sql = Util.readStr();
                    try {
                        ResultSet rs = stmt.executeQuery(sql); 
                        while (rs.next()) {
                            System.out.println(rs.getString(1));
                        }                        
                    } catch(SQLException e) {
                        System.out.println(e.getMessage()); 
                    }                    
                    break;                                                  

            case 5: System.out.println("Digite o comando sql");
                    sql = Util.readStr();
                    try {
                        int i = stmt.executeUpdate(sql); 
                        System.out.println(i+" linhas afetadas");
                    } catch(SQLException e) {
                        System.out.println(e.getMessage()); 
                    }                    
                    break;                                                  

            case 6: main();
                    break;
                    
            case 7: return;
        }        
        m();
    }
 
    private static void criarTabelas() throws SQLException {
        String sql = null;         
        sql = "CREATE TABLE " + login + "_FUNCIONARIO (LOGIN VARCHAR2(20) NOT NULL, SENHA VARCHAR2(20) NOT NULL, NOME VARCHAR2(30) NOT NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_FUNCIONARIO ADD ( PRIMARY KEY (LOGIN) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_QUEIXA (CODIGO NUMBER NOT NULL, TIPOQUEIXA NUMBER NOT NULL, SOLICITANTE VARCHAR2(55) NULL, DESCRICAO VARCHAR2(256) NULL, OBSERVACAO VARCHAR2(256) NULL, EMAIL VARCHAR2(55) NULL, FUNCIONARIO VARCHAR2(20) NULL, SITUACAO NUMBER NOT NULL, DATAPARECER DATE NULL, DATAQUEIXA DATE NULL, RUA VARCHAR2(55) NULL, COMPLEMENTO VARCHAR2(55) NULL, CEP VARCHAR2(20) NULL, UF VARCHAR2(20) NULL, FONE VARCHAR2(12) NULL, CIDADE VARCHAR2(30) NULL, BAIRRO VARCHAR2(30) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXA ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_QUEIXADIVERSA (CODIGO NUMBER NOT NULL, IDADE NUMBER NULL, INSTRUCAO VARCHAR2(55) NULL, OCUPACAO VARCHAR2(55) NULL, RUA VARCHAR2(55) NULL, COMPLEMENTO VARCHAR2(55) NULL, CEP VARCHAR2(20) NULL, UF VARCHAR2(20) NULL, FONE VARCHAR2(12) NULL, CIDADE VARCHAR2(30) NULL, BAIRRO VARCHAR2(30) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXADIVERSA ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_QUEIXADOENCA (CODIGO NUMBER NOT NULL, NOMEDOENTE VARCHAR2(55) NULL, IDADE NUMBER NOT NULL, SEXO VARCHAR2(55) NULL,DATAADOECEU DATE NULL, DOENCA NUMBER NULL, RUA VARCHAR2(55) NULL, COMPLEMENTO VARCHAR2(55) NULL, CEP VARCHAR2(20) NULL, UF VARCHAR2(20) NULL, FONE VARCHAR2(12) NULL, CIDADE VARCHAR2(30) NULL, BAIRRO VARCHAR2(30) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXADOENCA ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_QUEIXAALIMENTAR (CODIGO NUMBER NOT NULL, QTDECOMENSAIS NUMBER NULL, QTDEDOENTES NUMBER NULL, QTDEINTERNACOES NUMBER NULL, QTDEOBITOS NUMBER NULL, LOCALATENDIMENTO VARCHAR2(55) NULL, REFEICAOSUSPEITA VARCHAR2(55) NULL, RUA VARCHAR2(55) NULL, COMPLEMENTO VARCHAR2(55) NULL, CEP VARCHAR2(20) NULL, UF VARCHAR2(20) NULL, FONE VARCHAR2(12) NULL, CIDADE VARCHAR2(30) NULL, BAIRRO VARCHAR2(30) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXAALIMENTAR ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_QUEIXAANIMAL (CODIGO NUMBER NOT NULL, QTDEANIMAIS NUMBER NULL, DATAINCOMODO DATE NULL, ANIMAL VARCHAR2(55) NULL, RUA VARCHAR2(55) NULL, COMPLEMENTO VARCHAR2(55) NULL, CEP VARCHAR2(20) NULL, UF VARCHAR2(20) NULL, FONE VARCHAR2(12) NULL, CIDADE VARCHAR2(30) NULL, BAIRRO VARCHAR2(30) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXAANIMAL ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_TIPODOENCA (CODIGO NUMBER NOT NULL, NOME VARCHAR2(55) NULL, DESCRICAO VARCHAR2(256) NULL, MANIFESTACAO VARCHAR2(256) NULL, DURACAO VARCHAR2(55) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_TIPODOENCA ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_SINTOMA (CODIGO NUMBER NOT NULL, DESCRICAO VARCHAR2(55) NOT NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_SINTOMA ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_TIPODOENCASINTOMA (CODIGOTIPODOENCA NUMBER NOT NULL, CODIGOSINTOMA NUMBER NOT NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_TIPODOENCASINTOMA ADD ( PRIMARY KEY (CODIGOTIPODOENCA,CODIGOSINTOMA) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_UNIDADESAUDE (CODIGO NUMBER NOT NULL, DESCRICAO VARCHAR2(40) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_UNIDADESAUDE ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_UNIDADEESPECIALIDADE (CODIGOUNIDADESAUDE NUMBER NOT NULL,CODIGOESPECIALIDADE NUMBER NOT NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_UNIDADEESPECIALIDADE ADD ( PRIMARY KEY (CODIGOUNIDADESAUDE,CODIGOESPECIALIDADE) )";
        criarTabela(sql);
        sql = "CREATE TABLE " + login + "_ESPECIALIDADE (CODIGO NUMBER NOT NULL, DESCRICAO VARCHAR2(40) NULL)";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_ESPECIALIDADE ADD ( PRIMARY KEY (CODIGO) )";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXA ADD ( FOREIGN KEY (FUNCIONARIO) REFERENCES " + login + "_FUNCIONARIO(LOGIN) )";        
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXADIVERSA ADD ( FOREIGN KEY (CODIGO) REFERENCES " + login + "_QUEIXA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXADOENCA ADD ( FOREIGN KEY (CODIGO) REFERENCES " + login + "_QUEIXA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXADOENCA ADD ( FOREIGN KEY (DOENCA) REFERENCES " + login + "_TIPODOENCA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXAALIMENTAR ADD ( FOREIGN KEY (CODIGO) REFERENCES " + login + "_QUEIXA (CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_QUEIXAANIMAL ADD ( FOREIGN KEY (CODIGO) REFERENCES " + login + "_QUEIXA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_TIPODOENCASINTOMA ADD ( FOREIGN KEY (CODIGOTIPODOENCA) REFERENCES " + login + "_TIPODOENCA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_TIPODOENCASINTOMA ADD ( FOREIGN KEY (CODIGOSINTOMA) REFERENCES " + login + "_SINTOMA(CODIGO))";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_UNIDADEESPECIALIDADE ADD ( FOREIGN KEY (CODIGOUNIDADESAUDE) REFERENCES " + login + "_UNIDADESAUDE(CODIGO) )";
        criarTabela(sql);
        sql = "ALTER TABLE " + login + "_UNIDADEESPECIALIDADE ADD ( FOREIGN KEY (CODIGOESPECIALIDADE) REFERENCES " + login + "_ESPECIALIDADE (CODIGO) )";
        criarTabela(sql);
        sql = "CREATE SEQUENCE " + login + "_numeroqueixa start with 1 increment by 1";
        criarTabela(sql);
    }
    
    private static void povoarTabelas() throws SQLException {
        String sql;
        sql = "INSERT INTO " + login + "_FUNCIONARIO VALUES ('default','default','Funcionario Defaut')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADESAUDE VALUES (1, 'Ipsep')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADESAUDE VALUES (2, 'Restauracao')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADESAUDE VALUES (3, 'Portugues')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADESAUDE VALUES (4, 'Unimed Recife Pediatria')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_ESPECIALIDADE VALUES (1, 'Ginecologia')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_ESPECIALIDADE VALUES (2, 'Oftalmologia')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_ESPECIALIDADE VALUES (3, 'Pediatria')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_ESPECIALIDADE VALUES (4, 'Urologia')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (1, 1)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (1, 4)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (2, 1)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (2, 2)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (2, 3)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (2, 4)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (3, 2)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (3, 3)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_UNIDADEESPECIALIDADE VALUES (4, 3)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCA VALUES (1, 'Hepatite', 'Sindrome hepatica', 'Infeo', 'indeterminado')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCA VALUES (2, 'Gripe', 'Doena viral', 'continua', '1 semana')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_SINTOMA VALUES (1, 'Febre')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_SINTOMA VALUES (2, 'Convulsoes')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_SINTOMA VALUES (3, 'Vomitos')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_SINTOMA VALUES (4, 'Perda de peso')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_SINTOMA VALUES (5, 'Diarreia')";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCASINTOMA VALUES (1, 3)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCASINTOMA VALUES (1, 4)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCASINTOMA VALUES (2, 1)";
        criarTabela(sql);
        sql = "INSERT INTO " + login + "_TIPODOENCASINTOMA VALUES (2, 5)";
        criarTabela(sql);
    }

    private static void removerTabelas() throws SQLException {
        for (int i=0; i < TABELAS.length; i++) {
            try {
                removerTabela(login+TABELAS[i]);
            } catch(SQLException ex) {
                System.out.println(ex.getMessage());
                System.out.println("TABELA INDICE "+i);
            }
        }
        String sql;
        sql = "DROP SEQUENCE " + login + "_numeroqueixa";
        criarTabela(sql);
    }

    private static void esvaziarTabelas() throws SQLException {
        for (int i=0; i < TABELAS.length; i++) {
            try {
                esvaziarTabela(login+TABELAS[i]);
            } catch(SQLException ex) {
                System.out.println(ex.getMessage());
                System.out.println("TABELA INDICE "+i);
            }            
        }
        String sql;
        sql = "DROP SEQUENCE " + login + "_numeroqueixa";
        criarTabela(sql);
        sql = "CREATE SEQUENCE " + login + "_numeroqueixa start with 1 increment by 1";
        criarTabela(sql);
    }    
}