package gui.servlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Calendar;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import util.Date;
import util.HTMLCode;

import complaint.Complaint;
import complaint.FoodComplaint;

import controllers.HealthWatcherFacade;
import employee.Employee;
import exceptions.InvalidDateException;
import exceptions.ObjectAlreadyInsertedException;

public class ServletInsertFoodComplaint extends HttpServlet {

    private HealthWatcherFacade healthWatcher;

    public void init(ServletConfig config) throws ServletException {
        try {
            healthWatcher = HealthWatcherFacade.getInstance();
        } catch (Exception e) {
            System.out.println(e.getMessage()); 

            throw new ServletException(e.getMessage());
        }
    }

    public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        PrintWriter out;
        Complaint complaint;
        short qtdeComensais;
        short qtdeDoentes;
        short qtdeInternacoes;
        short qtdeObitos;

        response.setContentType("text/html");

        out = response.getWriter();

        try {

            //Complaint Normal
            String descricaoQueixa     = request.getParameter("descricaoQueixa");
            String observacaoQueixa    = request.getParameter("observacaoQueixa");
            String nomeSolicitante     = request.getParameter("nomeSolicitante");
            String ruaSolicitante      = request.getParameter("ruaSolicitante");
            String compSolicitante     = request.getParameter("compSolicitante");
            String bairroSolicitante   = request.getParameter("bairroSolicitante");
            String cidadeSolicitante   = request.getParameter("cidadeSolicitante");
            String ufSolicitante       = request.getParameter("ufSolicitante");
            String cepSolicitante      = request.getParameter("cepSolicitante");
            String telefoneSolicitante = request.getParameter("telefoneSolicitante");
            String emailSolicitante    = request.getParameter("emailSolicitante");

            //Complaint Alimentar
            String nomeVitima     = request.getParameter("nomeVitima");
            String ruaVitima      = request.getParameter("ruaVitima");
            String compVitima     = request.getParameter("compVitima");
            String bairroVitima   = request.getParameter("bairroVitima");
            String cidadeVitima   = request.getParameter("cidadeVitima");
            String ufVitima       = request.getParameter("ufVitima");
            String cepVitima      = request.getParameter("cepVitima");
            String telefoneVitima = request.getParameter("telefoneVitima");

            qtdeComensais   = Short.parseShort(request.getParameter("qtdeComensais"));
            qtdeDoentes     = Short.parseShort(request.getParameter("qtdeDoentes"));
            qtdeInternacoes = Short.parseShort(request.getParameter("qtdeInternacoes"));
            qtdeObitos      = Short.parseShort(request.getParameter("qtdeObitos"));

            String localAtendimento = request.getParameter("localAtendimento");
            String refeicaoSuspeita = request.getParameter("refeicaoSuspeita");
            Calendar agora          = Calendar.getInstance();

			Employee funcionarioAtendente = null;
			int statusQueixa = Complaint.COMPLAINT_OPENED;
			Date dataOpiniaoMedico = null;
			Date dataAtual = new Date(agora.get(Calendar.DAY_OF_MONTH), 
									  agora.get(Calendar.MONTH)+1,
									  agora.get(Calendar.YEAR));
															   
            complaint = new FoodComplaint(nomeSolicitante, 
            						      descricaoQueixa, 
            						      observacaoQueixa,
                                          emailSolicitante, 
                                          funcionarioAtendente, 
                                          statusQueixa, 
                                          dataOpiniaoMedico,
                                          dataAtual, 
                                          ruaSolicitante,
                                          compSolicitante,
                                          cepSolicitante,
                                          ufSolicitante,
                                          telefoneSolicitante,
                                          cidadeSolicitante,
                                          bairroSolicitante,
                                          qtdeComensais,
                                          qtdeDoentes, 
                                          qtdeInternacoes,
                                          qtdeObitos, 
                                          localAtendimento,
                                          refeicaoSuspeita, 
                                          ruaVitima, 
                                          compVitima,
                                          cepVitima, 
                                          ufVitima,
                                          telefoneVitima,
                                          cidadeVitima,
                                          bairroVitima);
            
            int codigo = this.healthWatcher.insert(complaint);

            out.println(HTMLCode.htmlPage("Complaint inserted", 
                                          "<p> <h2> Food Complaint inserted</h2> </p>" +
                                          "<p> <h2> Save the complaint number: " + codigo + "</h2> </p>"));                                          

        } catch (InvalidDateException e) {
            out.println(HTMLCode.errorPage("Date Invalida"));
        } catch (ObjectAlreadyInsertedException e) {
            out.println(HTMLCode.errorPage("Complaint already inserted"));
        } finally {
            out.close();
        }
    }
}