package gui.servlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Calendar;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import util.Date;
import util.HTMLCode;

import complaint.Complaint;
import complaint.SpecialComplaint;

import controllers.HealthWatcherFacade;
import employee.Employee;
import exceptions.InvalidDateException;
import exceptions.ObjectAlreadyInsertedException;

public class ServletInsertSpecialComplaint extends HttpServlet {

    private HealthWatcherFacade healthWatcher;

    public void init(ServletConfig config) throws ServletException {
        try {
            healthWatcher = HealthWatcherFacade.getInstance();
        } catch (Exception e) {
            System.out.println(e.getMessage()); 

            throw new ServletException(e.getMessage());
        }
    }

    public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        PrintWriter out;
        Complaint complaint;

        response.setContentType("text/html");

        out = response.getWriter();

        try {

            //Complaint Normal
            String descricaoQueixa     = request.getParameter("descricaoQueixa");
            String observacaoQueixa    = request.getParameter("observacaoQueixa");
            String nomeSolicitante     = request.getParameter("nomeSolicitante");
            String ruaSolicitante      = request.getParameter("ruaSolicitante");
            String compSolicitante     = request.getParameter("compSolicitante");
            String bairroSolicitante   = request.getParameter("bairroSolicitante");
            String cidadeSolicitante   = request.getParameter("cidadeSolicitante");
            String ufSolicitante       = request.getParameter("ufSolicitante");
            String cepSolicitante      = request.getParameter("cepSolicitante");
            String telefoneSolicitante = request.getParameter("telefoneSolicitante");

            String emailSolicitante    = request.getParameter("emailSolicitante");

            //Complaint Diversa
            short    idade              =
                Short.parseShort(request.getParameter("idade"));
            String instrucao          = request.getParameter("instrucao");
            String ocupacao           = request.getParameter("ocupacao");
            String ruaOcorrencia      = request.getParameter("ruaOcorrencia");
            String compOcorrencia     = request.getParameter("compOcorrencia");
            String bairroOcorrencia   = request.getParameter("bairroOcorrencia");
            String cidadeOcorrencia   = request.getParameter("cidadeOcorrencia");
            String ufOcorrencia       = request.getParameter("ufOcorrencia");
            String cepOcorrencia      = request.getParameter("cepOcorrencia");
            String telefoneOcorrencia = request.getParameter("telefoneOcorrencia");

            Calendar agora            = Calendar.getInstance();
			Date dataAtual = new Date(agora.get(Calendar.DAY_OF_MONTH), 
												  agora.get(Calendar.MONTH)+1,
												  agora.get(Calendar.YEAR));
												  
			Employee funcionarioAtendente = null;
			int statusQueixa = Complaint.COMPLAINT_OPENED;
			Date dataOpiniaoMedico = null;
			

            complaint = new SpecialComplaint(nomeSolicitante, 
            							     descricaoQueixa, 
            							     observacaoQueixa,
                                             emailSolicitante, 
											 funcionarioAtendente, 
											 statusQueixa, 
											 dataOpiniaoMedico,
											 dataAtual, 
                                             ruaSolicitante,
                                             compSolicitante,
                                             cepSolicitante,
                                             ufSolicitante,
                                             telefoneSolicitante,
                                             cidadeSolicitante,
                                             bairroSolicitante,
                                             idade,
                                             instrucao, 
                                             ocupacao, 
                                             ruaOcorrencia,
                                             compOcorrencia,
                                             cepOcorrencia,
                                             ufOcorrencia,
                                             telefoneOcorrencia,
                                             cidadeOcorrencia,
                                             bairroOcorrencia);

            int codigo = this.healthWatcher.insert(complaint);                       
                        
            out.println(HTMLCode.htmlPage("Complaint inserted", 
                                          "<p> <h2> Special Complaint inserted</h2> </p>" +
                                          "<p> <h2> Save the complaint number: " + codigo + "</h2> </p>"));

        } catch (InvalidDateException e) {
            out.println(HTMLCode.errorPage("Date Invalida"));
        } catch (ObjectAlreadyInsertedException e) {
            out.println(HTMLCode.errorPage("Complaint already inserted"));
        } finally {
            out.close();
        }
    }
}