package gui.servlets;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import util.Constants;
import util.HTMLCode;
import util.Library;
import controllers.HealthWatcherFacade;
import employee.Employee;
import exceptions.InvalidSessionException;
import exceptions.ObjectNotFoundException;

public class ServletLogin extends HttpServlet {

    private HealthWatcherFacade healthWatcher;

                       
	private String[] keywords = {"##SYSTEM_ROOT##",
			  			 		 "##SERVLET_SERVER_PATH##",
								 "##CLOSE##"};
                                  
	private String[] newWords = {Constants.SYSTEM_ROOT,
								 Constants.SERVLET_SERVER_PATH,
								 HTMLCode.closeAdministrator()};


    public static final String EMPLOYEE = "employee";

    public void init(ServletConfig config) throws ServletException {
        try {
            healthWatcher = HealthWatcherFacade.getInstance();
        } catch (Exception e) {
            System.out.println(e.getMessage()); 
            throw new ServletException(e.getMessage());
        }
    }

    public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        PrintWriter out;
        HttpSession session = request.getSession(false);
        
        response.setContentType("text/html");

        out = response.getWriter();

        try {
            if (session == null) {
                throw new InvalidSessionException("Invalid Session! <br><a href=\""+Constants.SYSTEM_LOGIN+"\">Try again</a>");
            }            
                                           
            out.println(Library.getFileListReplace(keywords, newWords, Constants.FORM_PATH+"MenuEmployee.html"));
        } catch (Exception e) {
            out.println(HTMLCode.errorPageAdministrator(e.getMessage()));
        } finally {           
            out.close();
        }

    }
    
    public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {        
                    
        PrintWriter out;
        HttpSession session = request.getSession(true);
        
        response.setContentType("text/html");

        out = response.getWriter();

        String login = request.getParameter("login");
        String password = request.getParameter("password");        

        try {
            Employee employee = healthWatcher.searchEmployee(login);
            
            if (employee.validatePassword(password)) {
                session.putValue(ServletLogin.EMPLOYEE, employee);
                                                              
                out.println(Library.getFileListReplace(keywords, newWords, Constants.FORM_PATH+"MenuEmployee.html"));                
            } else {                                 
                out.println(HTMLCode.errorPage("Invalid password! <br><a href=\""+Constants.SYSTEM_LOGIN+"\">Try again</a>"));
            }
        } catch (ObjectNotFoundException e) {
            out.println(HTMLCode.errorPage("Invalid login! <br><a href=\""+Constants.SYSTEM_LOGIN+"\">Try again</a>"));
        } catch (FileNotFoundException e) {
            out.println(HTMLCode.errorPage(e.getMessage()));
        } finally {           
            out.close();
        }
    }
}