package gui.servlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import util.Date;
import util.HTMLCode;

import complaint.AnimalComplaint;
import complaint.Complaint;
import complaint.FoodComplaint;
/* Cdigo de queixa diversa
import complaint.SpecialComplaint;
*/
import controllers.HealthWatcherFacade;
import exceptions.ObjectNotFoundException;

public class ServletSearchComplaintData extends HttpServlet {

    private HealthWatcherFacade healthWatcher;

    public void init(ServletConfig config) throws ServletException {
        try {
            healthWatcher = HealthWatcherFacade.getInstance();
        } catch (Exception e) {
            System.out.println(e.getMessage()); 

            throw new ServletException(e.getMessage());
        }
    }

    public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        PrintWriter out;

        response.setContentType("text/html");

        out = response.getWriter();

        int codQueixa = Integer.parseInt(request.getParameter("codQueixa"));

        try {
            
            Complaint complaint = healthWatcher.searchComplaint(codQueixa);

            out.println(HTMLCode.open("Queries - Complaints"));
    
            out.println("<body><h1>Search response<br>Complaint: " + codQueixa + "</h1>");

            out.println("<P>Complaint code: " + complaint.getCode() + "</P>");

            String type = null;

            if (complaint instanceof FoodComplaint)
	            type = "Food";
	        else if (complaint instanceof AnimalComplaint)
	            type = "Animal";
/* Cdigo de queixa diversa
			else if (complaint instanceof SpecialComplaint)
	            type = "Special";
            
*/
            out.println("<P>Complaint kind: " + type + "</P>");
            out.println("<P>Complainer: " + complaint.getComplainer() + "</P>");
            out.println("<P>E-mail: " + complaint.getEmail() + "</P>");
            out.println("<P>Complaint's description: " + complaint.getDescription() + "</P>");
            out.println("<P>Observation: " + complaint.getObservation() + "</P>");

            if (complaint.getComplaintDate() != null) {
                out.println("<P>Date: "
                            + Date.format(complaint.getComplaintDate(), Date.FORMATO1)
                            + "</P>");
            }

            String sit;

            if (complaint.getStatus() == Complaint.COMPLAINT_OPENED) {
                sit = "Opened";
            } else if (complaint.getStatus() == Complaint.COMPLAINT_CLOSED) {
                sit = "Closed";
            } else {
                sit = "Suspended";
            }

            out.println("<P>Status: " + sit + "</P>");

            if (complaint.getStatus() == Complaint.COMPLAINT_CLOSED) {
                if (complaint.getMedicalOpinionDate() != null) {
                    out.println("<P>Observation Date: " +
                                Date.format(complaint.getMedicalOpinionDate(), Date.FORMATO1) + "</P>");
                }

                if (complaint.getAttendant() != null) {
                    out.println("<P>Employee: " +
                                complaint.getAttendant().getName() + "</P>");
                }
            }

            out.println("<P>Complainer's address: " + complaint.getRuaComplainer()
                        + "," + complaint.getComplementoComplainer() + " Province: "
                        + complaint.getBairroComplainer() + " </P>");
            out.println("<P>ZIP code: " + complaint.getCepComplainer() + " City: "
                        + complaint.getCidadeComplainer() + " State: " + complaint.getUfComplainer()
                        + "</P>");
            out.println("<P> Phone number: " + complaint.getTelefoneComplainer() + "</P>");

            if (complaint instanceof FoodComplaint) {
                out.println("<P>Amount of people that ate the meal: " + ((FoodComplaint) complaint).getQtdComensais() + "</P>");
                out.println("<P>Amount of sick people: " + ((FoodComplaint) complaint).getQtdDoentes() + "</P>");
                out.println("<P>Amount of people checked into a hospital: " + ((FoodComplaint) complaint).getQtdInternacoes() + "</P>");
                out.println("<P>Amount of deaths: " + ((FoodComplaint) complaint).getQtdObitos() + "</P>");
                out.println("<P>Place of medical care: " + ((FoodComplaint) complaint).getLocalAtendimento() + "</P>");
                out.println("<P>Suspicious meal: " + ((FoodComplaint) complaint).getRefeicaoSuspeita() + "</P>");

                out.println("<P>Person sick's address: " + ((FoodComplaint) complaint).getRuaDoente()
                            + "," + ((FoodComplaint) complaint).getComplementoDoente() + " Province: "
                            + ((FoodComplaint) complaint).getBairroDoente() + " </P>");
                out.println("<P>ZIP code: " + ((FoodComplaint) complaint).getCepDoente() + " City: "
                            + ((FoodComplaint) complaint).getCidadeDoente() + " State: " + ((FoodComplaint) complaint).getUfDoente()
                            + "</P>");
                out.println("<P> Phone number: " + ((FoodComplaint) complaint).getTelefoneDoente() + "</P>");

            }

            if (complaint instanceof AnimalComplaint) {
                out.println("<P>Animal: " + ((AnimalComplaint) complaint).getTipoAnimal() + "</P>");
                out.println("<P>Amount of animals: " + ((AnimalComplaint) complaint).getQtdAnimais() + "</P>");

                if (((AnimalComplaint) complaint).getDataIncomodo() != null) {
                    out.println("<P>Date: " + 
                                Date.format(((AnimalComplaint) complaint).getDataIncomodo(), Date.FORMATO1) + "</P>");
                }

				out.println("<P>Victim's address: " + ((AnimalComplaint) complaint).getRuaOcorrencia()
							+ "," + ((AnimalComplaint) complaint).getComplementoOcorrencia() + " Province: "
							+ ((AnimalComplaint) complaint).getBairroOcorrencia() + " </P>");
				out.println("<P>ZIP code: " + ((AnimalComplaint) complaint).getCepOcorrencia() + " City: "
							+ ((AnimalComplaint) complaint).getCidadeOcorrencia() + " State: " 
							+ ((AnimalComplaint) complaint).getUfOcorrencia() + "</P>");
				out.println("<P> Phone number: " + ((AnimalComplaint) complaint).getTelefoneOcorrencia() + "</P>");

            }
/* Cdigo de queixa diversa
            if (complaint instanceof SpecialComplaint) {
                out.println("<P>Years old: " + ((SpecialComplaint) complaint).getAge()
                            + "</P>");
                out.println("<P>School level: "
                            + ((SpecialComplaint) complaint).getEducationLevel() + "</P>");
                out.println("<P>Ocuppation: "
                            + ((SpecialComplaint) complaint).getOccupation() + "</P>");

				out.println("<P>Event's address: " + ((SpecialComplaint) complaint).getRuaEvento()
							+ "," + ((SpecialComplaint) complaint).getComplementoEvento() + " Province: "
							+ ((SpecialComplaint) complaint).getBairroEvento() + " </P>");
				out.println("<P>ZIP code: " + ((SpecialComplaint) complaint).getCepEvento() + " City: "
							+ ((SpecialComplaint) complaint).getCidadeEvento() + " State: " 
							+ ((SpecialComplaint) complaint).getUfEvento() + "</P>");
				out.println("<P> Phone number: " + ((SpecialComplaint) complaint).getTelefoneEvento() + "</P>");
            }
*/            
            out.println(HTMLCode.closeQueries());
        } catch (ObjectNotFoundException e) {
            out.println(HTMLCode.errorPageQueries("This complaint does not exist"));
        } finally {
            out.close();
        }
    }
}