package gui.servlets;

import java.io.IOException;
import java.io.PrintWriter;

import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import util.ConcreteIterator;
import util.HTMLCode;
import util.IteratorHW;
import aspects.dataManagement.dataCollections.array.SymptomRepositoryArray;

import complaint.DiseaseType;
import complaint.Symptom;

import controllers.HealthWatcherFacade;
import exceptions.ObjectNotFoundException;

public class ServletSearchDiseaseData extends HttpServlet {

    private HealthWatcherFacade healthWatcher;

    public void init(ServletConfig config) throws ServletException {
        try {
            healthWatcher = HealthWatcherFacade.getInstance();
        } catch (Exception e) {
            System.out.println(e.getMessage()); 

            throw new ServletException(e.getMessage());
        }
    }

    public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
                    
        PrintWriter out;

        response.setContentType("text/html");

        out = response.getWriter();

        int codigoTipoDoenca = Integer.parseInt(request.getParameter("codTipoDoenca"));

        try {
            DiseaseType tp = healthWatcher.searchDiseaseType(codigoTipoDoenca);
            
            out.println(HTMLCode.open("Queries - Diseases"));
            out.println("<body><h1>Querie result<br>Disease</h1>");          

            out.println("<P><h3>Name: " + tp.getNome() + "</h3></P>");
            out.println("<P>Description: " + tp.getDescricao() + "</P>");
            out.println("<P>How manifests: " + tp.getManifestacao()
                        + " </P>");
            out.println("<P>Duration: " + tp.getDuracao() + " </P>");
            out.println("<P>Symptoms: </P>");

            IteratorHW repSintoma = new ConcreteIterator((SymptomRepositoryArray) tp.getSintomas());

            if (!repSintoma.hasNext()) {
                out.println("<P>There isn't registered symptoms.</P>");
            } else {
                Symptom s;

                do {
                    s = (Symptom) repSintoma.next();
                    out.println("<li> " + s.getDescricao() + " </li>");
                } while (repSintoma.hasNext());
            }
            out.println(HTMLCode.closeQueries());
        } catch (ObjectNotFoundException e) {
            out.println(HTMLCode.errorPageQueries("This disease does not exist"));
        } finally {
            out.close();
        }

    }
}